@@ -5,7 +5,7 @@ package Module::Install::ExtraTests;
 use Module::Install::Base;
 
 BEGIN {
-  our $VERSION = '0.004';
+  our $VERSION = '0.005';
   our $ISCORE  = 1;
   our @ISA     = qw{Module::Install::Base};
 }
@@ -34,7 +34,7 @@ sub extra_tests {
       my $is_author = $Module::Install::AUTHOR ? 1 : 0;
 
       return qq{\t$perl "-Iinc" "-MModule::Install::ExtraTests" }
-           . qq{"-e" "Module::Install::ExtraTests::__harness('Test::Harness', $is_author, '$a_str', '$r_str', '$s_str', \$(TEST_VERBOSE), '\$(INST_LIB)', '\$(INST_ARCHLIB)')" $tests\n};
+           . qq["-e" "Module::Install::ExtraTests::__harness('Test::Harness', (exists \\\$\$ENV{AUTHOR_TESTING} ? \\\$\$ENV{AUTHOR_TESTING} : $is_author), '$a_str', '$r_str', '$s_str', \$(TEST_VERBOSE), '\$(INST_LIB)', '\$(INST_ARCHLIB)')" $tests\n];
     }
 
     sub dist_test {
